==> apache-log4j-tools-0.8.0-src.zip: log4j-docgen/src/main/java/org/apache/logging/log4j/docgen/generator/DocumentationGeneratorArgs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.docgen.generator;

import static java.util.Objects.requireNonNull;

import java.nio.file.Path;
import java.util.Set;
import java.util.function.Predicate;
import org.apache.logging.log4j.docgen.PluginSet;

public final class DocumentationGeneratorArgs {

    final Set<PluginSet> pluginSets;

    final Predicate<String> classNameFilter;

    final Path templateDirectory;

    final DocumentationTemplate indexTemplate;

    final DocumentationTemplate typeTemplate;

    public DocumentationGeneratorArgs(
            final Set<PluginSet> pluginSets,
            final Predicate<String> classNameFilter,
            final Path templateDirectory,
            final DocumentationTemplate indexTemplate,
            final DocumentationTemplate typeTemplate) {
        this.pluginSets = requireNonNull(pluginSets, "pluginSets");
        this.classNameFilter = requireNonNull(classNameFilter, "classNameFilter");
        this.templateDirectory = requireNonNull(templateDirectory, "templateDirectory");
        this.indexTemplate = requireNonNull(indexTemplate, "indexTemplate");
        this.typeTemplate = requireNonNull(typeTemplate, "typeTemplate");
    }
}

==> apache-log4j-tools-0.9.0-src.zip: log4j-docgen/src/main/java/org/apache/logging/log4j/docgen/generator/DocumentationGeneratorArgs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.docgen.generator;

import static java.util.Objects.requireNonNull;

import java.nio.file.Path;
import java.util.Set;
import java.util.function.Predicate;
import org.apache.logging.log4j.docgen.PluginSet;

public final class DocumentationGeneratorArgs {

    final Set<PluginSet> pluginSets;

    final Predicate<String> classNameFilter;

    final Path templateDirectory;

    final Set<DocumentationTemplate> indexTemplates;

    final Set<DocumentationTemplate> typeTemplates;

    public DocumentationGeneratorArgs(
            final Set<PluginSet> pluginSets,
            final Predicate<String> classNameFilter,
            final Path templateDirectory,
            final Set<DocumentationTemplate> indexTemplates,
            final Set<DocumentationTemplate> typeTemplates) {
        this.pluginSets = requireNonNull(pluginSets, "pluginSets");
        this.classNameFilter = requireNonNull(classNameFilter, "classNameFilter");
        this.templateDirectory = requireNonNull(templateDirectory, "templateDirectory");
        this.indexTemplates = requireNonNull(indexTemplates, "indexTemplates");
        this.typeTemplates = requireNonNull(typeTemplates, "typeTemplates");
    }
}
